@@ -10,8 +10,7 @@ use Rose::HTML::Object::Messages
 use Rose::HTML::Form::Field::DateTime::StartDate;
 use Rose::HTML::Form::Field::DateTime::EndDate;
 
-use Rose::HTML::Form::Field::Compound;
-our @ISA = qw(Rose::HTML::Form::Field::Compound);
+use base 'Rose::HTML::Form::Field::Compound';
 
 use Rose::Object::MakeMethods::Generic
 (
@@ -24,7 +23,7 @@ use Rose::Object::MakeMethods::Generic
   ]
 );
 
-our $VERSION = '0.549';
+our $VERSION = '0.606';
 
 sub build_field
 {
@@ -253,6 +252,8 @@ if(__PACKAGE__->localizer->auto_load_messages)
   __PACKAGE__->localizer->load_all_messages;
 }
 
+use utf8; # The __DATA__ section contains UTF-8 text
+
 1;
 
 __DATA__
@@ -399,4 +400,4 @@ John C. Siracusa (siracusa@gmail.com)
 
 =head1 LICENSE
 
-Copyright (c) 2009 by John C. Siracusa.  All rights reserved.  This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+Copyright (c) 2010 by John C. Siracusa.  All rights reserved.  This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
