@@ -2,10 +2,9 @@ package Rose::HTML::Form::Field::DateTime::StartDate;
 
 use strict;
 
-use Rose::HTML::Form::Field::DateTime;
-our @ISA = qw(Rose::HTML::Form::Field::DateTime);
+use base 'Rose::HTML::Form::Field::DateTime';
 
-our $VERSION = '0.34';
+our $VERSION = '0.606';
 
 1;
 
@@ -51,4 +50,4 @@ John C. Siracusa (siracusa@gmail.com)
 
 =head1 LICENSE
 
-Copyright (c) 2009 by John C. Siracusa.  All rights reserved.  This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+Copyright (c) 2010 by John C. Siracusa.  All rights reserved.  This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
