@@ -8,10 +8,10 @@ use base 'Rose::HTML::Form::Field::Text';
 
 our $VERSION = '0.606';
 
-use Rose::Object::MakeMethods::Generic
-(
-  scalar => [ qw(min max) ],
-);
+# use Rose::Object::MakeMethods::Generic
+# (
+#   scalar => [ qw(min max) ],
+# );
 
 __PACKAGE__->default_html_attr_value(size  => 6);
 
@@ -229,4 +229,4 @@ John C. Siracusa (siracusa@gmail.com)
 
 =head1 LICENSE
 
-Copyright (c) 2009 by John C. Siracusa.  All rights reserved.  This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+Copyright (c) 2010 by John C. Siracusa.  All rights reserved.  This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
